Welcome to Raft!
==================

raft is a Python (3.4+) library for managing shell-oriented that is a fork
of the venerable invoke library.  Unlike invoke, raft takes after its
grandmother (fab) and preserves underscores in both command names and
argument names.
subprocesses and organizing executable Python code into CLI-invokable tasks. It
draws inspiration from various sources (``make``/``rake``, Fabric 1.x, etc) to
arrive at a powerful & clean feature set.

For a high level introduction, including example code, please see `our main
project website <http://pyinvoke.org>`_; or for detailed API docs, see `the
versioned API website <http://docs.pyinvoke.org>`_.
